/***************************************************************************
                          fleet.h  -  description
                             -------------------
    begin                : Tue Jan 22 2002
    copyright            : (C) 2002 by Michael Andreen
    email                : whale@linux.nu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FLEET_H
#define FLEET_H

#include <map>
#include <string>
#include <vector>

#include "unittype.h"

//!This is the engine for the whole battlesystem.
/**This is the engine for the whole battlesystem.
  *	One of the few parts that I plan make fully portable.
  *\todo LOTS (I think ;)
  *@author Michael Andreen
  */
class Fleet 
{
public: 
	Fleet();
	~Fleet();

	/**Sets the name that represents this fleet. Might be different a name
	 * like foobar or some coordinates like 1:1:1. The name doesn't have to be unique,
	 * since it's up to the rest of the program to handle that part.
	 * \see Name
	 */
	void   setName(std::string sName);
	/**Returns the name of this fleet.
	 * \see setName
	 */
	std::string Name();

	/**The race string decides what type of ships this fleet can have.
	 * The values must be feeded into this class.
	 * \param sRace This is just the name of the race. It's case-sensitive.
	 * \return If the race is available this function returns true, if not false is returned. The race is set in both cases though.
	 * \see Race
	 */
	bool   setRace(std::string sRace);
	/**Just returns what race this fleet belongs to.. 
	 * \return The race, represented as a string.
	 * \see setRace
	 */
	std::string Race();


protected:
	std::string	m_sName;
	std::string	m_sRace;
	std::map<std::string, std::vector<int> >	m_Fleet;

	static std::map<std::string, UnitType>	s_Units;
	static std::map<std::string, std::vector<int> > s_Races;
};

#endif
